@@ -1,7 +1,7 @@
 import sys
 import numpy
 from PyQt5.QtWidgets import QApplication
-from PyQt5.QtGui import QIntValidator, QDoubleValidator
+
 from orangewidget import gui
 from orangewidget.settings import Setting
 from oasys.widgets import gui as oasysgui, congruence
@@ -83,7 +83,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONENERGY = oasysgui.lineEdit(box1, self, "ELECTRONENERGY",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 1
@@ -91,7 +91,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONENERGYSPREAD = oasysgui.lineEdit(box1, self, "ELECTRONENERGYSPREAD",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 2
@@ -99,7 +99,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONCURRENT = oasysgui.lineEdit(box1, self, "ELECTRONCURRENT",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 3
@@ -107,7 +107,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONBEAMSIZEH = oasysgui.lineEdit(box1, self, "ELECTRONBEAMSIZEH",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 4
@@ -115,7 +115,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONBEAMSIZEV = oasysgui.lineEdit(box1, self, "ELECTRONBEAMSIZEV",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 5
@@ -123,7 +123,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONBEAMDIVERGENCEH = oasysgui.lineEdit(box1, self, "ELECTRONBEAMDIVERGENCEH",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 6
@@ -131,7 +131,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_ELECTRONBEAMDIVERGENCEV = oasysgui.lineEdit(box1, self, "ELECTRONBEAMDIVERGENCEV",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 7
@@ -139,7 +139,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_PERIODID = oasysgui.lineEdit(box1, self, "PERIODID",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 8
@@ -147,7 +147,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_NPERIODS = oasysgui.lineEdit(box1, self, "NPERIODS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 9
@@ -155,7 +155,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_KV = oasysgui.lineEdit(box1, self, "KV",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 9B
@@ -163,7 +163,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_KH = oasysgui.lineEdit(box1, self, "KH",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 9C
@@ -171,7 +171,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_KPHASE = oasysgui.lineEdit(box1, self, "KPHASE",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
 
@@ -182,7 +182,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "DISTANCE",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 11
@@ -190,7 +190,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "GAPH",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 12
@@ -198,7 +198,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "GAPV",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 11B
@@ -206,7 +206,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "GAPH_CENTER",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 12B
@@ -214,7 +214,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "GAPV_CENTER",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 13
@@ -222,7 +222,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "PHOTONENERGYMIN",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 14
@@ -230,7 +230,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "PHOTONENERGYMAX",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 15
@@ -238,7 +238,7 @@ class OWundulator_spectrum(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "PHOTONENERGYPOINTS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 16
